S_RES_PARTNER_GET = {"_id": {"type": "integer"}}

S_RES_PARTNER_RETURN_GET = {
    "id": {"type": "integer", "required": True},
    "email": {"type": "string", "required": True, "empty": False},
    "name": {"type": "string", "required": True, "empty": False},
    "address": {
        "type": "dict",
        "schema": {
            "street": {"type": "string"},
            "zip": {"type": "string"},
            "city": {"type": "string"},
            "state": {"type": "string"},
            "country": {"type": "string"},
        },
    },
    "lang": {"type": "string"}
}

S_RES_PARTNER_VALIDATE = {"_id": {"type": "integer"}}

S_RES_PARTNER_SEARCH = {
    "vat": {"type": "string", "nullable": True, "empty": True},
    "email": {"type": "string", "nullable": True, "empty": True},
    "phone": {"type": "string", "nullable": True, "empty": True}
}

S_RES_PARTNER_RETURN_SEARCH = {
    "count": {"type": "integer"},
    "rows": {
        "type": "list",
        "schema": {
            "type": "dict",
            "schema": {
                "id": {"type": "integer", "required": True},
                "email": {"type": "string", "required": True, "empty": False},
                "name": {"type": "string", "required": True, "empty": False},
                "address": {
                    "type": "dict",
                    "schema": {
                        "street": {"type": "string"},
                        "zip": {"type": "string"},
                        "city": {"type": "string"},
                        "state": {"type": "string"},
                        "country": {"type": "string"},
                    },
                },
                "lang": {"type": "string"}
            }
        }
    }
}



import logging

from werkzeug.exceptions import BadRequest, NotFound

from odoo import _
from odoo.fields import Date

from odoo.addons.base_rest.http import wrapJsonException
from odoo.addons.component.core import Component

from odoo.addons.sm_maintenance.models.models_api_services_utils import api_services_utils

from . import schemas

_logger = logging.getLogger(__name__)


class ResPartnerService(Component):
    _inherit = "emc.rest.service"
    _name = "res.partner.services"
    _usage = "res-partner"
    _description = """
    Subscription Request Services
  """

    def get(self, _id):
        partner = self.env["res.partner"].search(
            [("id", "=", _id)]
        )
        if partner:
            return self._to_dict(partner)
        else:
            raise wrapJsonException(
                NotFound(_("No partner for id %s") % _id)
            )

    def search(self, vat=None, email=None, phone=None):
        _logger.info("search by VAT: {}, email: {}, phone: {}".format(vat, email, phone))

        domain = []

        if vat:
            domain.append(("vat", "=", vat))
        if email:
            domain.append(("email", "=", email))
        if phone:
            domain.append(("phone", "=", phone))

        if not domain:
            return {"count": 0, "rows": []}

        requests = self.env["subscription.request"].search(domain)

        response = {
            "count": len(requests),
            "rows": [self._to_dict(sr) for sr in requests],
        }
        return response

    def validate(self, _id, **params):
        partner = self.env["res.partner"].search(
            [("_api_external_id", "=", _id)]
        )
        if not partner:
            raise wrapJsonException(
                NotFound(_("No partner for id %s") % _id)
            )
        partner.validate_res_partner()
        return self._to_dict(partner)

    def _to_dict(self, record):
        record.ensure_one()
        utils = api_services_utils.get_instance()
        address_attributes = {
            "street",
            "zip",
            "city",
            "state_id",
            "country_id"
        }
        rel_address_attributes = {
            "state_id": "code",
            "country_id": "code"
        }
        address_dict = utils.generate_get_dictionary(
            record, address_attributes, rel_address_attributes)
        attributes = {
            "name",
            "email",
            "lang"
        }
        record_dict = utils.generate_get_dictionary(record, attributes)
        record_dict['address'] = address_dict
        return record_dict

    def _validator_get(self):
        return schemas.S_RES_PARTNER_GET

    def _validator_return_get(self):
        return schemas.S_RES_PARTNER_RETURN_GET

    def _validator_validate(self):
        return schemas.S_RES_PARTNER_VALIDATE

    def _validator_return_validate(self):
        return schemas.S_RES_PARTNER_RETURN_GET

    def _validator_search(self):
        return schemas.S_RES_PARTNER_SEARCH

    def _validator_return_search(self):
        return schemas.S_RES_PARTNER_RETURN_SEARCH



# -*- coding: utf-8 -*-
{
  'name': "vertical_carsharing_rest_api",

  'summary': """
    Partner rest service""",

  'author': "Som Mobilitat",
  'website': "https://www.sommobilitat.coop",

  # Categories can be used to filter modules in modules listing
  # Check https://github.com/odoo/odoo/blob/11.0/odoo/addons/base/module/module_data.xml
  # for the full list
  'category': 'vertical-carsharing',
  'version': '12.0.0.0.2',

  # any module necessary for this one to work correctly
  'depends': [
    'base',
    'easy_my_coop_api'
  ],

  # always loaded
  'data': [

  ],
  # only loaded in demonstration mode
  'demo': [],
}
